@@ -18,7 +18,8 @@ except ImportError:
 
 from quart import Quart, request, abort, jsonify, websocket, Response
 
-from .api_impl import (AsyncApi, SyncApi, HttpApi, WebSocketReverseApi,
+from .api import AsyncApi, SyncApi
+from .api_impl import (SyncWrapperApi, HttpApi, WebSocketReverseApi,
                        UnifiedApi, ResultStore)
 from .bus import EventBus
 from .exceptions import Error, TimingError
@@ -31,7 +32,10 @@ from . import exceptions
 from .exceptions import *  # noqa: F401, F403
 
 __all__ = [
-    'CQHttp', 'Event', 'Message', 'MessageSegment',
+    'CQHttp',
+    'Event',
+    'Message',
+    'MessageSegment',
 ]
 __all__ += exceptions.__all__
 
@@ -39,8 +43,11 @@ __pdoc__ = {}
 
 
 def _deco_maker(deco_method: Callable, type_: str) -> Callable:
-    def deco_deco(self, arg: Optional[Union[str, Callable]] = None,
+
+    def deco_deco(self,
+                  arg: Optional[Union[str, Callable]] = None,
                   *sub_event_names: str) -> Callable:
+
         def deco(func: Callable) -> Callable:
             if isinstance(arg, str):
                 e = [type_ + '.' + e for e in [arg] + list(sub_event_names)]
@@ -51,7 +58,7 @@ def _deco_maker(deco_method: Callable, type_: str) -> Callable:
                 deco_method(self, type_)(func)
             return func
 
-        if isinstance(arg, Callable):
+        if callable(arg):
             return deco(arg)
         return deco
 
@@ -60,14 +67,14 @@ def _deco_maker(deco_method: Callable, type_: str) -> Callable:
 
 class CQHttp(AsyncApi):
     """
-    CQHTTP 机器人的主类，负责控制整个机器人的运行、事件处理函数的注册、与 CQHTTP
-    的连接、CQHTTP API 的调用等。
+    OneBot (CQHTTP) 机器人的主类，负责控制整个机器人的运行、事件处理函数的注册、OneBot
+    API 的调用等。
 
     内部维护了一个 `Quart` 对象作为 web 服务器，提供 HTTP 协议的 ``/`` 和 WebSocket
-    协议的 ``/ws/``、``/ws/api/``、``/ws/event/`` 端点供 CQHTTP 连接。
+    协议的 ``/ws/``、``/ws/api/``、``/ws/event/`` 端点供 OneBot 连接。
 
-    由于基类 `api_impl.AsyncApi` 继承了 `api.Api` 的 `__getattr__`
-    魔术方法，因此可以在 bot 对象上直接调用 CQHTTP API，例如：
+    由于基类 `api.AsyncApi` 继承了 `api.Api` 的 `__getattr__`
+    魔术方法，因此可以在 bot 对象上直接调用 OneBot API，例如：
 
     ```py
     await bot.send_private_msg(user_id=10001000, message='你好')
@@ -80,11 +87,13 @@ class CQHttp(AsyncApi):
     await bot.call_action('set_group_whole_ban', group_id=10010)
     ```
 
-    两种调用 API 的方法最终都通过 `CQHttp.api` 属性来向 CQHTTP
+    两种调用 API 的方法最终都通过 `CQHttp.api` 属性来向 OneBot
     发送请求并获取调用结果。
     """
 
-    def __init__(self, import_name: str = '', *,
+    def __init__(self,
+                 import_name: str = '',
+                 *,
                  api_root: Optional[str] = None,
                  access_token: Optional[str] = None,
                  secret: Optional[AnyStr] = None,
@@ -96,8 +105,8 @@ class CQHttp(AsyncApi):
         ``import_name`` 参数为当前模块（使用 `CQHttp` 的模块）的导入名，通常传入
         ``__name__`` 或不传入。
 
-        ``api_root`` 参数为 CQHTTP API 的 URL，``access_token`` 和
-        ``secret`` 参数为 CQHTTP 配置中填写的对应项。
+        ``api_root`` 参数为 OneBot API 的 URL，``access_token`` 和
+        ``secret`` 参数为 OneBot 配置中填写的对应项。
 
         ``message_class`` 参数为要用来对 `Event.message` 进行转换的消息类，可使用
         `Message`，例如：
@@ -113,7 +122,7 @@ class CQHttp(AsyncApi):
             assert isinstance(event.message, Message)
         ```
 
-        ``api_timeout_sec`` 参数用于设置 CQHTTP API 请求的超时时间，单位是秒。
+        ``api_timeout_sec`` 参数用于设置 OneBot API 请求的超时时间，单位是秒。
 
         ``server_app_kwargs`` 参数用于配置 `Quart` 对象，将以命名参数形式传给入其初始化函数。
         """
@@ -125,19 +134,16 @@ class CQHttp(AsyncApi):
 
         self._server_app = Quart(import_name, **(server_app_kwargs or {}))
         self._server_app.before_serving(self._before_serving)
-        self._server_app.add_url_rule('/', methods=['POST'],
+        self._server_app.add_url_rule('/',
+                                      methods=['POST'],
                                       view_func=self._handle_http_event)
         for p in ('/ws', '/ws/event', '/ws/api'):
-            self._server_app.add_websocket(p, strict_slashes=False,
+            self._server_app.add_websocket(p,
+                                           strict_slashes=False,
                                            view_func=self._handle_wsr)
 
-        self._configure(
-            api_root,
-            access_token,
-            secret,
-            message_class,
-            api_timeout_sec
-        )
+        self._configure(api_root, access_token, secret, message_class,
+                        api_timeout_sec)
 
     def _configure(self,
                    api_root: Optional[str] = None,
@@ -151,8 +157,10 @@ class CQHttp(AsyncApi):
         self._secret = secret
         self._api._http_api = HttpApi(api_root, access_token, api_timeout_sec)
         self._wsr_api_clients = {}  # connected wsr api clients
-        self._api._wsr_api = WebSocketReverseApi(
-            self._wsr_api_clients, api_timeout_sec)
+        self._wsr_event_clients = set()
+        self._api._wsr_api = WebSocketReverseApi(self._wsr_api_clients,
+                                                 self._wsr_event_clients,
+                                                 api_timeout_sec)
 
     async def _before_serving(self):
         self._loop = asyncio.get_running_loop()
@@ -179,13 +187,13 @@ class CQHttp(AsyncApi):
 
     @property
     def api(self) -> AsyncApi:
-        """`api_impl.AsyncApi` 对象，用于异步地调用 CQHTTP API。"""
+        """`api.AsyncApi` 对象，用于异步地调用 OneBot API。"""
         return self._api
 
     @property
     def sync(self) -> SyncApi:
         """
-        `api_impl.SyncApi` 对象，用于同步地调用 CQHTTP API，例如：
+        `api.SyncApi` 对象，用于同步地调用 OneBot API，例如：
 
         ```py
         @bot.on_message('group')
@@ -200,24 +208,31 @@ class CQHttp(AsyncApi):
             if not self._loop:
                 raise TimingError('attempt to access sync api '
                                   'before bot is running')
-            self._sync_api = SyncApi(self._api, self._loop)
+            self._sync_api = SyncWrapperApi(self._api, self._loop)
         return self._sync_api
 
-    def run(self, host: str = None, port: int = None, *args, **kwargs) -> None:
+    def run(self,
+            host: str = '127.0.0.1',
+            port: int = 8080,
+            *args,
+            **kwargs) -> None:
         """运行 bot 对象，实际就是运行 Quart app，参数与 `Quart.run` 一致。"""
         if 'use_reloader' not in kwargs:
             kwargs['use_reloader'] = False
         self._server_app.run(host=host, port=port, *args, **kwargs)
 
-    def run_task(self, host: str = None, port: int = None,
-                 *args, **kwargs) -> Coroutine[None, None, None]:
+    def run_task(self,
+                 host: str = '127.0.0.1',
+                 port: int = 8080,
+                 *args,
+                 **kwargs) -> Coroutine[None, None, None]:
         if 'use_reloader' not in kwargs:
             kwargs['use_reloader'] = False
         return self._server_app.run_task(host=host, port=port, *args, **kwargs)
 
     async def call_action(self, action: str, **params) -> Any:
         """
-        通过内部维护的 `api_impl.AsyncApi` 具体实现类调用 CQHTTP API，``action``
+        通过内部维护的 `api.AsyncApi` 具体实现类调用 OneBot API，``action``
         为要调用的 API 动作名，``**params`` 为 API 所需参数。
         """
         return await self._api.call_action(action=action, **params)
@@ -229,7 +244,7 @@ class CQHttp(AsyncApi):
 
         ``event`` 参数为事件对象，``message`` 参数为要发送的消息。可额外传入 ``at_sender``
         命名参数用于控制是否 at 事件的触发者，默认为 `False`。其它命名参数作为
-        CQHTTP API ``send_msg`` 的参数直接传递。
+        OneBot API ``send_msg`` 的参数直接传递。
         """
         msg = message if isinstance(message, Message) else Message(message)
         await run_async_funcs(self._before_sending_funcs, event, msg, kwargs)
@@ -447,8 +462,6 @@ class CQHttp(AsyncApi):
             global groups
             groups = await bot.get_group_list(self_id=event.self_id)
         ```
-
-        注：仅支持 CQHTTP v4.14+。
         """
         return self.on_meta_event('lifecycle.connect')(func)
 
@@ -501,6 +514,7 @@ class CQHttp(AsyncApi):
             await self._handle_wsr_universal()
 
     async def _handle_wsr_event(self) -> None:
+        self._add_wsr_event_client()
         try:
             while True:
                 try:
@@ -514,7 +528,7 @@ class CQHttp(AsyncApi):
 
                 asyncio.create_task(self._handle_event_with_response(payload))
         finally:
-            pass
+            self._remove_wsr_event_client()
 
     async def _handle_wsr_api(self) -> None:
         self._add_wsr_api_client()
@@ -529,6 +543,7 @@ class CQHttp(AsyncApi):
 
     async def _handle_wsr_universal(self) -> None:
         self._add_wsr_api_client()
+        self._add_wsr_event_client()
         try:
             while True:
                 try:
@@ -548,6 +563,7 @@ class CQHttp(AsyncApi):
                     # is a api result
                     ResultStore.add(payload)
         finally:
+            self._remove_wsr_event_client()
             self._remove_wsr_api_client()
 
     def _add_wsr_api_client(self) -> None:
@@ -563,6 +579,14 @@ class CQHttp(AsyncApi):
             # that is, the self_id may be '*'
             del self._wsr_api_clients[self_id]
 
+    def _add_wsr_event_client(self) -> None:
+        ws = websocket._get_current_object()
+        self._wsr_event_clients.add(ws)
+
+    def _remove_wsr_event_client(self) -> None:
+        ws = websocket._get_current_object()
+        self._wsr_event_clients.discard(ws)
+
     async def _handle_event(self, payload: Dict[str, Any]) -> Any:
         ev = Event.from_payload(payload)
         if not ev:
@@ -573,13 +597,14 @@ class CQHttp(AsyncApi):
 
         if self._message_class and 'message' in ev:
             ev['message'] = self._message_class(ev['message'])
-        results = list(filter(lambda r: r is not None,
-                              await self._bus.emit(event_name, ev)))
+        results = list(
+            filter(lambda r: r is not None, await
+                   self._bus.emit(event_name, ev)))
         # return the first non-none result
         return results[0] if results else None
 
-    async def _handle_event_with_response(
-            self, payload: Dict[str, Any]) -> None:
+    async def _handle_event_with_response(self, payload: Dict[str,
+                                                              Any]) -> None:
         response = await self._handle_event(payload)
         if isinstance(response, dict):
             payload.pop('message', None)  # avoid wasting bandwidth
@@ -590,7 +615,7 @@ class CQHttp(AsyncApi):
                 await self._api.call_action(
                     self_id=payload['self_id'],
                     action='.handle_quick_operation_async',
-                    context=payload, operation=response
-                )
+                    context=payload,
+                    operation=response)
             except Error:
                 pass
